
Installation
========================

This part of the documentation covers the installation of Delver.
The first step to using any software package is getting it properly installed.


$ pip install requests
----------------------

To install Delver, simply run this simple command in your terminal of choice::

    $ pip install delver


Get the Source Code
-------------------

Delver is actively developed on GitHub, where the code is
`always available <https://github.com//requests>`_.

You can either clone the public repository::

    $ git clone git://github.com/nuncjo/Delver.git

